 % Growth accounting for the United States

clc; clear all; close all;

% Open data set
load('USMacrodata.mat');
TSize = length(USMacrodata.Quarter);
% Parameter values
alpha = 0.33;
delta = 0.03;

% 1. Generate time series for capital stock

% Initial condition for captial stock
i_avg = mean(USMacrodata.GPDIC96(1:8,1));
y_avg = mean(USMacrodata.GDPC1(1:8,1));
k_initial = (1/delta)*i_avg/y_avg*USMacrodata.GDPC1(1,1);

% Iterate on capital accumulation equation
capital = zeros(TSize, 1);
capital(1,1) = k_initial;

for t = 2:1:TSize
    capital(t,1) = (1-delta)*capital(t-1,1) + USMacrodata.GPDIC96(t,1);
end
clear t y_avg i_avg k_initial;

% 2. Generate time series with (logarithmic) first differences
Delta_Y = log(USMacrodata.GDPC1(2:end)) - log(USMacrodata.GDPC1(1:end-1));
Delta_N = log(USMacrodata.HOANBS(2:end)) - log(USMacrodata.HOANBS(1:end-1));
Delta_K = log(capital(2:end)) - log(capital(1:end-1));

% 3. Back out the growth rate of TFP
Delta_TFP =  Delta_Y - (1-alpha)*Delta_N - alpha*Delta_K;

% 4. Compute decade averages
means = zeros(4,6); % Store end results here

Datenumber = USMacrodata.Datenumber(2:end,1);
temp = datevec(Datenumber);
Startindex = [1950, 1960, 1970, 1980, 1990, 2000];
Endindex   = [1959, 1969, 1979, 1989, 1999, 2009];

for t = 1:1:length(Startindex)
    I_Start = find(temp(:,1) == Startindex(t), 1,'First');
    I_End   = find(temp(:,1) == Endindex(t), 1, 'First');
    means(1,t) = mean(Delta_Y(I_Start:I_End));
    means(2,t) = mean(Delta_N(I_Start:I_End));
    means(3,t) = mean(Delta_K(I_Start:I_End));
    means(4,t) = mean(Delta_TFP(I_Start:I_End));
end
clear t temp Datenumber TSize Startindex Endindex;


% 5. Compute the level of TFP and plot it
temp = [1; Delta_TFP];
Level_TFP = cumsum(temp);
clear temp;
figure;
plot(USMacrodata.Quarter, Level_TFP);
xlim([1947,2013]);
title('TFP');
